@@ -24,7 +24,7 @@
 
 //======================================================================
 // undef
-#ifdef INCG_IRIS_IUTEST_HPP_
+#if defined(INCG_IRIS_IUTEST_HPP_)
 
 #undef IUTEST_PACKAGE
 #undef IUTEST_HAS_PACKAGE
