@@ -90,6 +90,9 @@
 #elif defined(__AVR32__) || defined(__avr32__)
 #  define IUTEST_OS_AVR32				1
 #  define IUTEST_PLATFORM				"AVR32"
+#elif defined(__arm__)
+#  define IUTEST_OS_ARM					1
+#  define IUTEST_PLATFORM				"ARM"
 #endif
 
 #if defined(IUTEST_OS_LINUX_ANDROID)
@@ -123,6 +126,10 @@
 #    if _MSC_VER > 1500
 #      define IUTEST_HAS_NULLPTR	1
 #    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER > 1200
+#      define IUTEST_HAS_NULLPTR	1
+#    endif
 #  endif
 #endif
 
@@ -144,6 +151,10 @@
 #    if _MSC_VER >= 1600
 #      define IUTEST_HAS_DECLTYPE	1
 #    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1200
+#      define IUTEST_HAS_DECLTYPE	1
+#    endif
 #  endif
 #endif
 
@@ -165,6 +176,10 @@
 #    if _MSC_VER >= 1600
 #      define IUTEST_HAS_STATIC_ASSERT	1
 #    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER > 1100
+#      define IUTEST_HAS_STATIC_ASSERT	1
+#    endif
 #  endif
 #endif
 
@@ -176,28 +191,26 @@
 //! has constexpr
 #if !defined(IUTEST_HAS_CONSTEXPR)
 #  if   defined(__clang__)
-#    if !__has_feature(cxx_constexpr)
-#      define IUTEST_HAS_CONSTEXPR	0
+#    if __has_feature(cxx_constexpr)
+#      define IUTEST_HAS_CONSTEXPR	1
 #    endif
 #  elif defined(__GNUC__)
-#    if (__GNUC__ < 4 || (__GNUC__ == 4 && __GNUC_MINOR__ < 6)) || !defined(__GXX_EXPERIMENTAL_CXX0X__)
-#      define IUTEST_HAS_CONSTEXPR	0
+#    if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 5)) && defined(__GXX_EXPERIMENTAL_CXX0X__)
+#      define IUTEST_HAS_CONSTEXPR	1
 #    endif
 #  elif defined(_MSC_VER)
 #    if _MSC_VER >= 1900 || _MSC_FULL_VER == 180021114
 #      define IUTEST_HAS_CONSTEXPR	1
-#    else
-#      define IUTEST_HAS_CONSTEXPR	0
 #    endif
-#  elif defined(__MWERKS__)
-#    define IUTEST_HAS_CONSTEXPR	0
-#  else
-#    define IUTEST_HAS_CONSTEXPR	0
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1400
+#      define IUTEST_HAS_CONSTEXPR	1
+#    endif
 #  endif
 #endif
 
 #if !defined(IUTEST_HAS_CONSTEXPR)
-#  define IUTEST_HAS_CONSTEXPR		1
+#  define IUTEST_HAS_CONSTEXPR		0
 #endif
 
 #if IUTEST_HAS_CONSTEXPR
@@ -218,8 +231,14 @@
 #    if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 2)) && defined(__GXX_EXPERIMENTAL_CXX0X__)
 #      define IUTEST_HAS_RVALUE_REFS	1
 #    endif
-#  elif defined(_MSC_VER) && (_MSC_VER >= 1700)
-#    define IUTEST_HAS_RVALUE_REFS	1
+#  elif defined(_MSC_VER)
+#    if (_MSC_VER >= 1700)
+#      define IUTEST_HAS_RVALUE_REFS	1
+#    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1200
+#      define IUTEST_HAS_RVALUE_REFS	1
+#    endif
 #  endif
 #endif
 
@@ -241,6 +260,10 @@
 #    if defined(_MSC_FULL_VER) && (_MSC_FULL_VER >= 180020827)
 #      define IUTEST_HAS_DELETED_FUNCTIONS	1
 #    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1200
+#      define IUTEST_HAS_DELETED_FUNCTIONS	1
+#    endif
 #  endif
 #endif
 
@@ -269,6 +292,10 @@
 #    if defined(_MSC_FULL_VER) && (_MSC_FULL_VER >= 180020827)
 #      define IUTEST_HAS_DEFAULT_FUNCTIONS	1
 #    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1200
+#      define IUTEST_HAS_DEFAULT_FUNCTIONS	1
+#    endif
 #  endif
 #endif
 
@@ -304,6 +331,10 @@
 #      define IUTEST_HAS_INITIALIZER_LIST	1
 #      include <initializer_list>
 #    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1400
+#      define IUTEST_HAS_INITIALIZER_LIST	1
+#    endif
 #  endif
 #endif
 
@@ -329,6 +360,10 @@
 #      define IUTEST_HAS_VARIADIC_TEMPLATES	1
 #      define IUTEST_HAS_VARIADIC_COMBINE	0
 #    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER > 1200
+#      define IUTEST_HAS_VARIADIC_TEMPLATES	1
+#    endif
 #  endif
 #endif
 
@@ -348,6 +383,8 @@
 #    endif
 #  elif defined(_MSC_VER)
 #    define IUTEST_HAS_VARIADIC_TEMPLATE_TEMPLATES	IUTEST_HAS_VARIADIC_TEMPLATES
+#  elif defined(__INTEL_COMPILER)
+#    define IUTEST_HAS_VARIADIC_TEMPLATE_TEMPLATES	IUTEST_HAS_VARIADIC_TEMPLATES
 #  endif
 #endif
 
@@ -366,6 +403,13 @@
 #      define IUTEST_HAS_CHAR16_T	1
 #    endif
 #  elif defined(_MSC_VER)
+#    if _MSC_VER >= 1900
+#      define IUTEST_HAS_CHAR16_T	1
+#    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1400
+#      define IUTEST_HAS_CHAR16_T	1
+#    endif
 #  endif
 #endif
 
@@ -384,6 +428,13 @@
 #      define IUTEST_HAS_CHAR32_T	1
 #    endif
 #  elif defined(_MSC_VER)
+#    if _MSC_VER >= 1900
+#      define IUTEST_HAS_CHAR32_T	1
+#    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1400
+#      define IUTEST_HAS_CHAR32_T	1
+#    endif
 #  endif
 #endif
 
@@ -404,6 +455,10 @@
 #      define IUTEST_HAS_LAMBDA		1
 #      define IUTEST_NO_LAMBDA_SCOPE_RESOLUTION	// VC++10 lambda v1.0 is not supported.
 #    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1200
+#      define IUTEST_HAS_LAMBDA		1
+#    endif
 #  endif
 #endif
 
@@ -435,6 +490,10 @@
 #    if (_MSC_VER >= 1800) || (_MSC_FULL_VER == 170051025)
 #      define IUTEST_HAS_EXPLICIT_CONVERSION	1
 #    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1300
+#      define IUTEST_HAS_EXPLICIT_CONVERSION	1
+#    endif
 #  endif
 #endif
 
@@ -465,6 +524,10 @@
 #    if _MSC_VER >= 1700
 #      define IUTEST_HAS_OVERRIDE_AND_FINAL	1
 #    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1400
+#      define IUTEST_HAS_OVERRIDE_AND_FINAL	1
+#    endif
 #  endif
 #endif
 
@@ -501,8 +564,12 @@
 #      define IUTEST_HAS_NOEXCEPT	1
 #    endif
 #  elif defined(_MSC_VER)
-#    if _MSC_FULL_VER == 180021114
-//#      define IUTEST_HAS_NOEXCEPT	1	// build fail
+#    if _MSC_FULL_VER >= 190022310
+//#      define IUTEST_HAS_NOEXCEPT	1 // https://connect.microsoft.com/VisualStudio/feedback/details/809079/torino-compile-error-template-noexcept
+#    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1400
+#      define IUTEST_HAS_NOEXCEPT	1
 #    endif
 #  endif
 #endif
@@ -549,9 +616,13 @@
 //! has extern template
 #if !defined(IUTEST_HAS_EXTERN_TEMPLATE)
 #  if defined(_MSC_VER) && _MSC_VER >= 1400
-#    define IUTEST_HAS_EXTERN_TEMPLATE	1
+#    define IUTEST_HAS_EXTERN_TEMPLATE		1
 #  elif defined(__GNUC__) || defined(__clang__)
-#    define IUTEST_HAS_EXTERN_TEMPLATE	1
+#    define IUTEST_HAS_EXTERN_TEMPLATE		1
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER > 1100
+#      define IUTEST_HAS_EXTERN_TEMPLATE	1
+#    endif
 #  endif
 #endif
 
@@ -573,6 +644,10 @@
 #    if _MSC_VER >= 1700
 #      define IUTEST_HAS_STRONG_ENUMS	1
 #    endif
+#  elif defined(__INTEL_COMPILER)
+#    if __INTEL_COMPILER >= 1400
+#      define IUTEST_HAS_STRONG_ENUMS	1
+#    endif
 #  endif
 #endif
 
@@ -581,26 +656,6 @@
 #endif
 
 // c++
-// attribute
-
-//! unused attribute
-#if !defined(IUTEST_ATTRIBUTE_UNUSED_)
-#  if (defined(__GNUC__) && !defined(COMPILER_ICC)) || defined(__clang__)
-#    define IUTEST_ATTRIBUTE_UNUSED_	__attribute__ ((unused))
-#  else
-#    define IUTEST_ATTRIBUTE_UNUSED_
-#  endif
-#endif
-
-//! pure attribute
-#if !defined(IUTEST_ATTRIBUTE_PURE_)
-#  if defined(__GNUC__) && !defined(COMPILER_ICC)
-#    define IUTEST_ATTRIBUTE_PURE_		__attribute__ ((pure))
-#  else
-#    define IUTEST_ATTRIBUTE_PURE_
-#  endif
-#endif
-
 //! has exceptions
 #if !defined(IUTEST_HAS_EXCEPTIONS)
 #  if   defined(_MSC_VER) || defined(__BORLANDC__)
@@ -648,6 +703,11 @@
 #    if __has_feature(cxx_rtti)
 #      define IUTEST_HAS_RTTI	1
 #    endif
+#    if defined(_MSC_VER)	// clang for windows
+#      if !defined(_CPPRTTI)
+#        include <exception>
+#      endif
+#    endif
 #  elif defined(__GNUC__)
 #    ifdef __RTTI
 #      define IUTEST_HAS_RTTI	1
@@ -682,7 +742,7 @@
 #  include <typeinfo>
 #endif
 
-// explicit instantiation access checking
+//! explicit instantiation access checking
 #if !defined(IUTEST_EXPLICIT_INSTANTIATION_ACCESS_PRIVATE_MEMBER_FUNCTION)
 #  if defined(_MSC_VER) && ((_MSC_VER < 1600) || (_MSC_VER == 1900))
      // VS2008 以前では、private なメンバー関数に explicit instantiation でもアクセスできない
@@ -692,7 +752,7 @@
 #  endif
 #endif
 
-// explicit instantiation access checking (static member function)
+//! explicit instantiation access checking (static member function)
 #if !defined(IUTEST_EXPLICIT_INSTANTIATION_ACCESS_PRIVATE_STATIC_MEMBER_FUNCTION)
 #  if defined(_MSC_VER)
 // Visual Studio では、private な static メンバー関数に explicit instantiation でもアクセスできない
@@ -733,13 +793,6 @@
 #  endif
 #endif
 
-// partial template specialization
-#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
-#  if defined(_MSC_VER) && (_MSC_VER < 1310)
-#    define IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION	1
-#  endif
-#endif
-
 //! explicit class member template specialization
 #if !defined(IUTEST_HAS_CLASS_MEMBER_TEMPLATE_SPECIALIZATION)
 #  if defined(_MSC_VER)
@@ -749,6 +802,13 @@
 #  endif
 #endif
 
+//! partial template specialization
+#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
+#  if defined(_MSC_VER) && (_MSC_VER < 1310)
+#    define IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION	1
+#  endif
+#endif
+
 //! has Two pahse name lookup
 #if !defined(IUTEST_NO_TWO_PHASE_NAME_LOOKUP)
 #  if defined(_MSC_VER)
@@ -756,49 +816,49 @@
 #  endif
 #endif
 
-// function template ordering
+//! function template ordering
 #if !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING)
 #  if defined(_MSC_VER) && (_MSC_VER < 1310)
 #    define IUTEST_NO_FUNCTION_TEMPLATE_ORDERING		1
 #  endif
 #endif
 
-// in class member initialization
+//! in class member initialization
 #if !defined(IUTEST_NO_INCLASS_MEMBER_INITIALIZATION)
 #  if defined(_MSC_VER) && _MSC_VER < 1310
 #    define IUTEST_NO_INCLASS_MEMBER_INITIALIZATION		1
 #  endif
 #endif
 
-// explicit function template instantiation
+//! explicit function template instantiation
 #if !defined(IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS)
 #  if defined(_MSC_VER) && _MSC_VER < 1310
 #    define IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS	1
 #  endif
 #endif
 
-// SFINAE
+//! SFINAE
 #if !defined(IUTEST_NO_SFINAE)
 #  if defined(_MSC_VER) && _MSC_VER < 1310
 #    define IUTEST_NO_SFINAE	1
 #  endif
 #endif
 
-// template template
+//! template template
 #if !defined(IUTEST_NO_TEMPLATE_TEMPLATES)
 #  if defined(_MSC_VER) && _MSC_VER < 1310
 #    define IUTEST_NO_TEMPLATE_TEMPLATES	1
 #  endif
 #endif
 
-// void return
+//! void return
 #if !defined(IUTEST_NO_VOID_RETURNS)
 #  if defined(_MSC_VER) && _MSC_VER < 1300
 #    define IUTEST_NO_VOID_RETURNS			1
 #  endif
 #endif
 
-// ADL
+//! ADL
 #if !defined(IUTEST_NO_ARGUMENT_DEPENDENT_LOOKUP)
 #  if defined(_MSC_VER) && _MSC_VER < 1310
 #    define IUTEST_NO_ARGUMENT_DEPENDENT_LOOKUP	1
@@ -811,7 +871,7 @@
 #  endif
 #endif
 
-// secure lib
+//! secure lib
 #if !defined(IUTEST_HAS_WANT_SECURE_LIB)
 #  if defined(_MSC_VER)
 #    if defined(__STDC_WANT_SECURE_LIB__) && __STDC_WANT_SECURE_LIB__
@@ -865,6 +925,55 @@
 #  define IUTEST_HAS_ANALYSIS_ASSUME		0
 #endif
 
+// attribute
+
+//! unused attribute
+#if !defined(IUTEST_ATTRIBUTE_UNUSED_)
+#  if (defined(__GNUC__) && !defined(COMPILER_ICC)) || defined(__clang__)
+#    define IUTEST_ATTRIBUTE_UNUSED_	__attribute__ ((unused))
+#  else
+#    define IUTEST_ATTRIBUTE_UNUSED_
+#  endif
+#endif
+
+//! pure attribute
+#if !defined(IUTEST_ATTRIBUTE_PURE_)
+#  if defined(__GNUC__) && !defined(COMPILER_ICC)
+#    define IUTEST_ATTRIBUTE_PURE_		__attribute__ ((pure))
+#  else
+#    define IUTEST_ATTRIBUTE_PURE_
+#  endif
+#endif
+
+//! noreturn
+#if !defined(IUTEST_ATTRIBUTE_NORETURN_)
+#  if   defined(__clang__)
+#    if __has_feature(cxx_attributes)
+#      define IUTEST_ATTRIBUTE_NORETURN_	[[noreturn]]
+#    elif __has_attribute(noreturn)
+#      define IUTEST_ATTRIBUTE_NORETURN_	__attribute__ ((noreturn))
+#    endif
+#  elif defined(__GNUC__) && !defined(COMPILER_ICC)
+#    define IUTEST_ATTRIBUTE_NORETURN_		__attribute__ ((noreturn))
+#  elif defined(_MSC_VER)
+#    define IUTEST_ATTRIBUTE_NORETURN_		__declspec(noreturn)
+#  endif
+#endif
+
+#if !defined(IUTEST_ATTRIBUTE_NORETURN_)
+#  define IUTEST_ATTRIBUTE_NORETURN_
+#endif
+
+// workaround
+#if defined(_MSC_VER)
+// http://stackoverflow.com/questions/14487241/avoiding-an-inheritance-by-dominance-warning-for-a-mocked-stdfstream-class
+#  define IUTEST_WORKAROUND_MSC_STLSTREAM_C4250()	\
+	void _Add_vtordisp1() {}	\
+	void _Add_vtordisp2() {}
+#else
+#  define IUTEST_WORKAROUND_MSC_STLSTREAM_C4250()	
+#endif
+
 // pragma
 #include "iutest_pragma.hpp"
 
