@@ -111,6 +111,9 @@
 #endif
 
 #if !defined(IUTEST_HAS_MATCHERS)
+/**
+ * @brief	IUTEST_*_THAT が使用可能かどうか
+*/
 #  define IUTEST_HAS_MATCHERS		1
 #endif
 
@@ -127,7 +130,7 @@
 
 #if !defined(IUTEST_HAS_BITWISE_EXPRESSION_DECOMPOSE)
 /**
-* @brief	式アサーションでビット演算子の展開をサポートするかどうか
+ * @brief	式アサーションでビット演算子の展開をサポートするかどうか
 */
 #  if IUTEST_HAS_DECLTYPE
 #    define IUTEST_HAS_BITWISE_EXPRESSION_DECOMPOSE		1
@@ -223,9 +226,18 @@
 #  endif
 #endif
 
+#if !defined(IUTEST_HAS_MATCHER_ELEMENTSARE)
+//! ::iutest::ElementsAre matcher が使用可能かどうか
+#  if IUTEST_HAS_TUPLE && IUTEST_HAS_MATCHERS
+#    define IUTEST_HAS_MATCHER_ELEMENTSARE		1
+#  else
+#    define IUTEST_HAS_MATCHER_ELEMENTSARE		0
+#  endif
+#endif
+
 #if !defined(IUTEST_HAS_MATCHER_ALLOF_AND_ANYOF)
 //! ::iutest::AllOf, ::iutest::AnyOf matcher が使用可能かどうか
-#  if IUTEST_HAS_TUPLE
+#  if IUTEST_HAS_TUPLE && IUTEST_HAS_MATCHERS
 #    define IUTEST_HAS_MATCHER_ALLOF_AND_ANYOF	1
 #  else
 #    define IUTEST_HAS_MATCHER_ALLOF_AND_ANYOF	0
@@ -248,10 +260,18 @@
 #  endif
 #endif
 
+#if !defined(IUTEST_HAS_LAMBDA_STATEMENTS)
+//! lambda を使った statements 展開が可能かどうか
+#  if IUTEST_HAS_LAMBDA && !defined(IUTEST_NO_LAMBDA_SCOPE_RESOLUTION)
+#    define IUTEST_HAS_LAMBDA_STATEMENTS		1
+#  else
+#    define IUTEST_HAS_LAMBDA_STATEMENTS		0
+#  endif
+#endif
 
 #if !defined(IUTEST_HAS_SPI_LAMBDA_SUPPORT)
 //! spi マクロで lambda を使って変数にアクセス可能かどうか
-#  if IUTEST_HAS_LAMBDA && !defined(IUTEST_NO_LAMBDA_SCOPE_RESOLUTION)
+#  if IUTEST_HAS_LAMBDA_STATEMENTS
 #    define IUTEST_HAS_SPI_LAMBDA_SUPPORT		1
 #  else
 #    define IUTEST_HAS_SPI_LAMBDA_SUPPORT		0
@@ -306,13 +326,22 @@
 
 #if !defined(IUTEST_HAS_PRINT_TO)
 //! PrintTo が使用可能かどうか
-#  if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION) && !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING)
+#  if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION) && !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING) && !defined(IUTEST_NO_ARGUMENT_DEPENDENT_LOOKUP)
 #    define IUTEST_HAS_PRINT_TO		1
 #  else
 #    define IUTEST_HAS_PRINT_TO		0
 #  endif
 #endif
 
+#if !defined(IUTEST_HAS_VARIADIC_PRED)
+//! 可変長述語アサーションが使用可能かどうか
+#  if IUTEST_HAS_VARIADIC_TEMPLATES && !defined(IUTEST_NO_VARIADIC_MACROS)
+#    define IUTEST_HAS_VARIADIC_PRED		1
+#  else
+#    define IUTEST_HAS_VARIADIC_PRED		0
+#  endif
+#endif
+
 #if !defined(IUTEST_HAS_ASSERTION_RETURN)
 //! ::iutest::AssertionReturn が使用可能かどうか
 #  if !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING)
@@ -322,6 +351,15 @@
 #  endif
 #endif
 
+#if !defined(IUTEST_HAS_ASSERTION_NOEQUALTO_OBJECT)
+//! IUTEST_*_EQ で operator == がないオブジェクトの検証が可能かどうか
+#  if !defined(IUTEST_NO_FUNCTION_TEMPLATE_ORDERING) && !defined(IUTEST_NO_ARGUMENT_DEPENDENT_LOOKUP)
+#    define IUTEST_HAS_ASSERTION_NOEQUALTO_OBJECT	1
+#  else
+#    define IUTEST_HAS_ASSERTION_NOEQUALTO_OBJECT	0
+#  endif
+#endif
+
 #if !defined(IUTEST_HAS_TESTNAME_ALIAS)
 //! テスト名の別名指定記法が使用できるかどうか
 #  if !defined(IUTEST_NO_VARIADIC_MACROS)
@@ -474,6 +512,14 @@
 #  define IUTEST_HAS_STRSTREAM		0
 #endif
 
+/**
+ * @brief	stdout/stderr の StreamCapture が使用可能かどうか
+*/
+#if !defined(IUTEST_HAS_STREAMCAPTURE)
+#  define IUTEST_HAS_STREAMCAPTURE	1
+#endif
+
+
 /**
  * @}
 */
@@ -508,7 +554,7 @@
 #define IUTEST_GetMillisec()	//!< 現在時刻のミリ秒取得関数を独自定義
 
 /**
-* @}
+ * @}
 */
 
 
@@ -597,7 +643,7 @@
 #elif _MSC_VER == 1900
 #  define IUTEST_LIB_TOOLSET	"vc140"
 #else
-#  error unkown _MSC_VER.
+#  error unknown _MSC_VER.
 #endif
 
 #if defined(_DEBUG)
