@@ -17,18 +17,18 @@
 
 //======================================================================
 // define
-#define	IUTEST_VER			0x01090100u	//!< iutest version 1.9.1.0
+#define IUTEST_VER			0x01110000u //!< iutest version 1.11.0.0
 #define IUTEST_MAJORVER		0x01u		//!< Major Version
-#define IUTEST_MINORVER		0x09u		//!< Minor Version
-#define IUTEST_BUILD		0x01u		//!< Build
+#define IUTEST_MINORVER		0x11u		//!< Minor Version
+#define IUTEST_BUILD		0x00u		//!< Build
 #define IUTEST_REVISION		0x00u		//!< Revision
 
 /**
  * @mainpage
  * @sa	@b	ProjectHome \n
  *			sourceforge : http://sourceforge.jp/projects/iutest/ \n
- *			github      : https://github.com/srz-zumix/iutest \n
- *          google group: https://groups.google.com/forum/?fromgroups#!forum/g-iutest \n
+ *			github		: https://github.com/srz-zumix/iutest \n
+ *			google group: https://groups.google.com/forum/?fromgroups#!forum/g-iutest \n
  *
  * @par		copyright
  * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
@@ -81,6 +81,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    <tr><td>--iutest_repeat                   </td><td>&lt;count&gt;</td><td>Set the number of repetitions of the test.</td></tr>
    <tr><td>--iutest_stream_result_to         </td><td>&lt;host:port&gt;</td><td>Set stream test results server.</td></tr>
    <tr><td>--iutest_file_location            </td><td>&lt;auto|vs|gcc&gt;</td><td>Format file location messages.</td></tr>
+   <tr><td>--iutest_default_package_name     </td><td>[name]</td><td>Set default root package name.</td></tr>
+   <tr><td>--verbose                         </td><td></td><td>Verbose option.</td></tr>
    <tr><td>--feature                         </td><td></td><td>Show iutest feature.</td></tr>
    <tr><td>--version, -v                     </td><td></td><td>Show iutest version.</td></tr>
  </table>
@@ -103,13 +105,46 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    <tr><td>IUTEST_PRINT_TIME=0|1           </td><td>Setting the display of elapsed time.</td></tr>
    <tr><td>IUTEST_REPEAT=count             </td><td>Set the number of repetitions of the test.</td></tr>
    <tr><td>IUTEST_FILE_LOCATION=auto|vs|gcc</td><td>Format file location messages.</td></tr>
+   <tr><td>IUTEST_ROOT_PACKAGE_NAME=[name] </td><td>Set root package name.</td></tr>
  </table>
 */
 
 /**
- * @page	CHANGELOG		変更履歴
+ * @page	CHANGELOG	変更履歴
  * @par		Changes
  <ul>
+  <li>v1.11.0.0
+    <ul>
+      <li>fused-src 対応</li>
+      <li>Wandbox 対応</li>
+      <li>Matcher に Eq,Ne,Le,Lt,Ge,Gt,IsNull,NotNull,TypeEq を追加</li>
+      <li>Matcher に StrEq,StrNe,StrCaseEq,StrCaseNe,HasSubstr を追加</li>
+      <li>Matcher に FloatEq,DoubleEq,NanSensitiveFloatEq,NanSensitiveDoubleEq を追加</li>
+      <li>Matcher に Not,ResultOf,Pointee を追加</li>
+      <li>コンテナMatcher に Each,ContainerEq,Pointwise,At,IsEmpty,SizeIs,ElementsAre,ElementsAreArray を追加</li>
+	  <li>コンテナMatcher の Contains から HasSubstr 機能を削除</li>
+	  <li>コンテナMatcher の条件に Matcher を使えるように修正</li>
+      <li>メンバーMatcher に Key,Pair,Field を追加</li>
+      <li>ワイルドカードMatcher A,_ を追加</li>
+      <li>IUTEST_*_FLOAT_EQ,DOUBLE_EQ で NAN の比較が真を返す不具合を修正</li>
+	  <li>Visual Studio 2015 Preview 対応</li>
+	  </ul>
+  </li>
+  <li>v1.10.0.0
+    <ul>
+      <li>--verbose コマンドラインオプションを追加</li>
+      <li>--iutest_default_package_name コマンドラインオプションを追加</li>
+      <li>operatoer == のないオブジェクトの IUTEST_*_EQ 対応</li>
+      <li>operatoer != のないオブジェクトの IUTEST_*_NE 対応</li>
+      <li>junit xml 出力に対応（--iutest_output=junit）</li>
+      <li>tuple の要素を取得する GetParam template 関数を追加</li>
+      <li>IUTEST_FLAG(ostream_formatter) を追加</li>
+      <li>tuple 要素を取得する GetParam tempalate 関数を追加</li>
+      <li>ARM対応</li>
+      <li>--iutest_break_on_failure でスキップや警告でも停止していた不具合を修正</li>
+      <li>Visual Studio 14 CTP 3 対応</li>
+    </ul>
+  </li>
   <li>v1.9.1.0
     <ul>
       <li>IUTEST_P,IUTEST_TYPED_TEST_P で DISABLED_ 指定が機能しない問題を修正</li>
@@ -544,15 +579,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
 /**
- * @example		main.cpp
- * @example		assertion.cpp
- * @example		disabledtest.cpp
- * @example		exception.cpp
- * @example		fixture.cpp
- * @example		parameterized.cpp
- * @example		printto.cpp
- * @example		simple.cpp
- * @example		typed.cpp
+ * @example main.cpp
+ * @example assertion.cpp
+ * @example disabledtest.cpp
+ * @example exception.cpp
+ * @example fixture.cpp
+ * @example matcher.cpp
+ * @example parameterized.cpp
+ * @example printto.cpp
+ * @example simple.cpp
+ * @example typed.cpp
 */
 
 #endif // INCG_IRIS_IUTEST_VER_HPP_D65CB7A7_D2AD_40FE_8F5F_8FBF376A0010_
