@@ -4,9 +4,7 @@
  * @file		iutest_shuffle_tests.cpp
  * @brief		シャッフルテスト対応テスト
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
  * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
@@ -17,7 +15,7 @@
 
 //======================================================================
 // include
-#include "../include/iutest.hpp"
+#include "iutest.hpp"
 
 static unsigned int seed = 0;
 static int count = 0;
@@ -72,7 +70,7 @@ int main(int argc, char* argv[])
 #endif
 {
 	MyEnvironment* const env = new MyEnvironment();
-	IUTEST_ASSERT( ::iutest::AddGlobalTestEnvironment(env) == env );
+	IUTEST_ASSERT_EXIT( ::iutest::AddGlobalTestEnvironment(env) == env );
 	IUTEST_INIT(&argc, argv);
 	
 	::iutest::IUTEST_FLAG(repeat) = 3;
@@ -83,6 +81,7 @@ int main(int argc, char* argv[])
 	
 	IUTEST_EXPECT_NE(order[0], order[1]);
 	IUTEST_EXPECT_NE(order[0], order[2]);
+	IUTEST_EXPECT_NE(order[1], order[2]);
 	
 	return ::iutest::UnitTest::GetInstance()->Passed() ? 0 : 1;
 }
